@@ -7,9 +7,9 @@ from ctypes import (
     c_void_p,
     c_wchar_p
 )
-from .winConst import *
 from .method import method
-from config import _LRESULT
+from . import _LRESULT
+
 class JsRunPy():
     def __init__(self,miniblink):
 
